@@ -4,7 +4,13 @@ import hashlib
 import time
 import os
 import urllib
-
+import socket
+from email import Encoders
+from email.mime.base import MIMEBase
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+from email.header import Header
+import smtplib
 def send_sms(mobile_numbers=None,content=None):
     '''
     send SMS
@@ -27,7 +33,7 @@ def send_sms(mobile_numbers=None,content=None):
        else:
             return (True,0)
     except Exception,err:
-        return (False,'-1')
+        return (False,-1)
 """
 check the file wether expire or not
 if the file's modify time is older than 7 day,return True,else return false
@@ -78,15 +84,45 @@ def get_nodes(machineroom='bj'):
         return hosts.split('\n')[:-1] #remove trial blank item
 """
 convert ip address to hex-digigtal style
-@returns: hex number 
+@returns: hexdecimal string
 example:
-127.0.0.1 --> 0x2130706433
+127.0.0.1 --> 0x7f000001
 """    
-def iptoint(ip):
-    return hex(socket.inet_aton(ip).encode('hex'),16)
-def inttoip(ip):
+def ip2int(ip):
+    return "0x%s" % socket.inet_aton(ip).encode('hex')
+    
+"""
+convert number-format ip address to string-format ipaddress
+the number maybe decimal or hexdecimal
+@returns: ip address string
+example:
+133169153 -> 127.0.0.1
+0x7f000001 -> 127.0.0.1
+"""
+def int2ip(ip):
     #convert int to hexdecimal whether it is or not
     ipint=hex(ip)
     return socket.inet_ntoa(ipint[2:].zfill(8).decode('hex'))
+    
+def send_mail(host='localhost',port=25,username=None,password=None,subject=None,sender='nobody@notice1.haodou.com',to=None,content=None):
+    msg = MIMEMultipart('alternative')
+    msg['Subject'] = subject
+    msg['Content-Type'] = "text/html; charset=utf-8"
+    msg['From'] = sender
+    #msg['To'] = toEmail
+    msg['To'] = ', '.join(to) #';'.join(toEmail)
+    part = MIMEText(content, _subtype='html',_charset='utf-8')
+    msg.attach(part)
+    s = smtplib.SMTP(host,port)
+    if username:
+        try:
+            s.login(username,password)
+        except Exception,err:
+            print "failed to login: %s" % err
+    #s.login(mail_username, mail_password)
+    #print msg.as_string()
+    s.sendmail(sender,to,msg.as_string())
+    s.quit()
+    
        
     
\ No newline at end of file
